# DISTRIBUTIONS

Distributions is a Python library for dealing with calculation of Gaussian and Binomial Distributions.

## Installation

Use the package manager [pip](https://pypi.org/project/distributions-oop-tut) to install foobar.

```bash
pip install distributions-oop-tut
```

## Usage

```python
from .Gaussiandistribution import Gaussian
from .Binomialdistribution import Binomial

gaussian_one = Gaussian(22, 2)
guas
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)